==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/de_de/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Es gibt keine Tickets, die den Suchkriterien entsprechen.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Letzte Antwort';
$lang['AdminTickets.search.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.search.heading_department_name'] = 'Abteilung';
$lang['AdminTickets.search.heading_status'] = 'Status';
$lang['AdminTickets.search.heading_priority'] = 'Priorität';
$lang['AdminTickets.search.heading_code'] = 'Ticket-Nummer';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Tickets suchen für "%1$s"';
$lang['AdminTickets.client.no_results'] = 'Derzeit gibt es keine Tickets mit diesem Status.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Letzte Antwort';
$lang['AdminTickets.client.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.client.heading_department_name'] = 'Abteilung';
$lang['AdminTickets.client.heading_priority'] = 'Priorität';
$lang['AdminTickets.client.heading_code'] = 'Ticket-Nummer';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Eintrittskarten';
$lang['AdminTickets.client.categorylink_createticket'] = 'Ticket öffnen';
$lang['AdminTickets.client.category_trash'] = 'Papierkorb';
$lang['AdminTickets.client.category_closed'] = 'Geschlossen';
$lang['AdminTickets.client.category_on_hold'] = 'In der Warteschleife';
$lang['AdminTickets.client.category_in_progress'] = 'In Arbeit';
$lang['AdminTickets.client.category_awaiting_reply'] = 'Erwartete Antwort des Kunden';
$lang['AdminTickets.client.category_open'] = 'Antwort der Dienststellen abwarten';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Datei entfernen';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Dateien zum Hochladen hier ablegen oder zum Auswählen von Dateien anklicken';
$lang['AdminTickets.reply.staff_title'] = 'Unterstützungspersonal';
$lang['AdminTickets.reply.system'] = 'System';
$lang['AdminTickets.reply.log_date'] = '%1$s von %2$s %3$s';
$lang['AdminTickets.reply.reply_date'] = 'Am %1$s %2$s %3$s geantwortet';
$lang['AdminTickets.reply.refresh_link'] = 'Zum Anzeigen anklicken.';
$lang['AdminTickets.reply.refresh'] = 'Es gibt neue Antworten oder Statusänderungen.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Weiter';
$lang['AdminTickets.reply.field_replysubmit'] = 'Ticket aktualisieren';
$lang['AdminTickets.reply.text_add_attachment'] = 'Anhang hinzufügen';
$lang['AdminTickets.reply.field_attachments'] = 'Anhänge';
$lang['AdminTickets.reply.field_note'] = 'Hinweis';
$lang['AdminTickets.reply.field_reply'] = 'Antwort';
$lang['AdminTickets.reply.heading_reply'] = 'Antwort hinzufügen';
$lang['AdminTickets.reply.text_with_selected'] = 'Führen Sie mit ausgewählten Antworten aus:';
$lang['AdminTickets.reply.text_add_response'] = 'Einfügen einer vordefinierten Antwort';
$lang['AdminTickets.reply.heading_date_added'] = 'Datum Eröffnet';
$lang['AdminTickets.reply.heading_status'] = 'Status';
$lang['AdminTickets.reply.heading_priority'] = 'Priorität';
$lang['AdminTickets.reply.heading_staff_id'] = 'Zugewiesen an';
$lang['AdminTickets.reply.heading_department'] = 'Abteilung';
$lang['AdminTickets.reply.heading_client'] = 'Kunde';
$lang['AdminTickets.reply.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Ticket #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Datei entfernen';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Dateien zum Hochladen hier ablegen oder zum Auswählen von Dateien anklicken';
$lang['AdminTickets.add.text_add_response'] = 'Einfügen einer vordefinierten Antwort';
$lang['Admintickets.add.client_placeholder'] = 'Kunden-ID oder Name';
$lang['AdminTickets.add.field_addsubmit'] = 'Ticket öffnen';
$lang['AdminTickets.add.text_add_attachment'] = 'Anhang hinzufügen';
$lang['AdminTickets.add.field_details'] = 'Einzelheiten';
$lang['AdminTickets.add.field_attachments'] = 'Anhänge';
$lang['AdminTickets.add.heading_status'] = 'Status';
$lang['AdminTickets.add.heading_priority'] = 'Priorität';
$lang['AdminTickets.add.heading_staff_id'] = 'Zugewiesen an';
$lang['AdminTickets.add.heading_department'] = 'Abteilung';
$lang['AdminTickets.add.heading_client'] = 'Kunde';
$lang['AdminTickets.add.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.add.text_no_clients'] = 'Keine Kunden gefunden. Versuchen Sie die Suche erneut.';
$lang['AdminTickets.add.heading_search_client'] = 'Suche nach dem Kunden';
$lang['AdminTickets.add.boxtitle_add'] = 'Ticket öffnen';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Einreichen';
$lang['AdminTickets.index.text_no_tickets'] = 'Keine offenen Tickets gefunden. Versuchen Sie die Suche erneut.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Ticket-Nummer';
$lang['AdminTickets.index.text_to_status'] = 'Wechseln zu:';
$lang['AdminTickets.index.text_to_client'] = 'An den Kunden:';
$lang['AdminTickets.index.text_into_ticket'] = 'In Ticket:';
$lang['AdminTickets.index.text_with_selected'] = 'Mit ausgewählten Tickets auftreten:';
$lang['AdminTickets.index.no_results'] = 'Derzeit gibt es keine Tickets mit diesem Status.';
$lang['AdminTickets.index.last_reply_by'] = 'von';
$lang['AdminTickets.index.unassigned'] = 'Nicht zugewiesen';
$lang['AdminTickets.index.field_last_reply'] = 'Letzte Antwort';
$lang['AdminTickets.index.field_assigned_staff'] = 'Zugewiesen an';
$lang['AdminTickets.index.field_summary'] = 'Zusammenfassung';
$lang['AdminTickets.index.field_department_id'] = 'Abteilung';
$lang['AdminTickets.index.field_priority'] = 'Priorität';
$lang['AdminTickets.index.field_ticket_number'] = 'Ticket-Nummer';
$lang['AdminTickets.index.hours'] = '%1$s Stunden';
$lang['AdminTickets.index.hour'] = '1 Stunde';
$lang['AdminTickets.index.minutes'] = '%1$s Minuten';
$lang['AdminTickets.index.any'] = 'Jede';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Letzte Antwort';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Zugewiesen an';
$lang['AdminTickets.index.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.index.heading_department_name'] = 'Abteilung';
$lang['AdminTickets.index.heading_priority'] = 'Priorität';
$lang['AdminTickets.index.heading_client'] = 'Kunde';
$lang['AdminTickets.index.heading_code'] = 'Ticket-Nummer';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Eintrittskarten';
$lang['AdminTickets.index.categorylink_createticket'] = 'Ticket öffnen';
$lang['AdminTickets.index.category_trash'] = 'Papierkorb';
$lang['AdminTickets.index.category_closed'] = 'Geschlossen';
$lang['AdminTickets.index.category_on_hold'] = 'In der Warteschleife';
$lang['AdminTickets.index.category_in_progress'] = 'In Arbeit';
$lang['AdminTickets.index.category_awaiting_reply'] = 'Erwartete Antwort des Kunden';
$lang['AdminTickets.index.category_open'] = 'Antwort der Dienststellen abwarten';
$lang['AdminTickets.text.unassigned'] = 'Nicht zugewiesen';
$lang['AdminTickets.search.page_title'] = 'Suchergebnisse für "%1$s"';
$lang['AdminTickets.reply.page_title'] = 'Support Manager > Ticket #%1$s';
$lang['AdminTickets.add.page_title'] = 'Support Manager > Ticket öffnen';
$lang['AdminTickets.index.page_title'] = 'Support Manager > Anfragen';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Es sind noch keine Mitarbeiter und/oder Abteilungen erstellt worden. Klicken Sie oben auf %1$s, um eine Abteilung zu erstellen, oder auf %2$s, um ein Personalmitglied zuzuweisen.';
$lang['AdminTickets.!success.ticket_delete'] = 'Die ausgewählten Tickets wurden erfolgreich gelöscht.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Die ausgewählten Tickets wurden erfolgreich aktualisiert.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Die ausgewählten Tickets wurden erfolgreich neu zugewiesen.';
$lang['AdminTickets.!success.ticket_merge'] = 'Die ausgewählten Tickets wurden erfolgreich in Ticket #%1$s zusammengeführt.';
$lang['AdminTickets.!success.ticket_split'] = 'Das Ticket #%1$s wurde erfolgreich in Ticket #%2$s aufgeteilt.';
$lang['AdminTickets.!success.ticket_updated'] = 'Das Ticket #%1$s wurde erfolgreich aktualisiert.';
$lang['AdminTickets.!success.ticket_created'] = 'Das Ticket #%1$s wurde erfolgreich geöffnet.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/de_de/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Es gibt keine Tickets, die den Suchkriterien entsprechen.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Letzte Antwort';
$lang['AdminTickets.search.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.search.heading_department_name'] = 'Abteilung';
$lang['AdminTickets.search.heading_status'] = 'Status';
$lang['AdminTickets.search.heading_priority'] = 'Priorität';
$lang['AdminTickets.search.heading_code'] = 'Ticket-Nummer';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Tickets suchen für "%1$s"';
$lang['AdminTickets.client.no_results'] = 'Derzeit gibt es keine Tickets mit diesem Status.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Letzte Antwort';
$lang['AdminTickets.client.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.client.heading_department_name'] = 'Abteilung';
$lang['AdminTickets.client.heading_priority'] = 'Priorität';
$lang['AdminTickets.client.heading_code'] = 'Ticket-Nummer';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Eintrittskarten';
$lang['AdminTickets.client.categorylink_createticket'] = 'Ticket öffnen';
$lang['AdminTickets.client.category_trash'] = 'Papierkorb';
$lang['AdminTickets.client.category_closed'] = 'Geschlossen';
$lang['AdminTickets.client.category_on_hold'] = 'In der Warteschleife';
$lang['AdminTickets.client.category_in_progress'] = 'In Arbeit';
$lang['AdminTickets.client.category_awaiting_reply'] = 'Erwartete Antwort des Kunden';
$lang['AdminTickets.client.category_open'] = 'Antwort der Dienststellen abwarten';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Datei entfernen';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Dateien zum Hochladen hier ablegen oder zum Auswählen von Dateien anklicken';
$lang['AdminTickets.reply.staff_title'] = 'Unterstützungspersonal';
$lang['AdminTickets.reply.system'] = 'System';
$lang['AdminTickets.reply.log_date'] = '%1$s von %2$s %3$s';
$lang['AdminTickets.reply.reply_date'] = 'Am %1$s %2$s %3$s geantwortet';
$lang['AdminTickets.reply.refresh_link'] = 'Zum Anzeigen anklicken.';
$lang['AdminTickets.reply.refresh'] = 'Es gibt neue Antworten oder Statusänderungen.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Weiter';
$lang['AdminTickets.reply.field_replysubmit'] = 'Ticket aktualisieren';
$lang['AdminTickets.reply.text_add_attachment'] = 'Anhang hinzufügen';
$lang['AdminTickets.reply.field_attachments'] = 'Anhänge';
$lang['AdminTickets.reply.field_note'] = 'Hinweis';
$lang['AdminTickets.reply.field_reply'] = 'Antwort';
$lang['AdminTickets.reply.heading_reply'] = 'Antwort hinzufügen';
$lang['AdminTickets.reply.text_with_selected'] = 'Führen Sie mit ausgewählten Antworten aus:';
$lang['AdminTickets.reply.text_add_response'] = 'Einfügen einer vordefinierten Antwort';
$lang['AdminTickets.reply.heading_date_added'] = 'Datum Eröffnet';
$lang['AdminTickets.reply.heading_status'] = 'Status';
$lang['AdminTickets.reply.heading_priority'] = 'Priorität';
$lang['AdminTickets.reply.heading_staff_id'] = 'Zugewiesen an';
$lang['AdminTickets.reply.heading_department'] = 'Abteilung';
$lang['AdminTickets.reply.heading_client'] = 'Kunde';
$lang['AdminTickets.reply.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Ticket #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Datei entfernen';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Dateien zum Hochladen hier ablegen oder zum Auswählen von Dateien anklicken';
$lang['AdminTickets.add.text_add_response'] = 'Einfügen einer vordefinierten Antwort';
$lang['Admintickets.add.client_placeholder'] = 'Kunden-ID oder Name';
$lang['AdminTickets.add.field_addsubmit'] = 'Ticket öffnen';
$lang['AdminTickets.add.text_add_attachment'] = 'Anhang hinzufügen';
$lang['AdminTickets.add.field_details'] = 'Einzelheiten';
$lang['AdminTickets.add.field_attachments'] = 'Anhänge';
$lang['AdminTickets.add.heading_status'] = 'Status';
$lang['AdminTickets.add.heading_priority'] = 'Priorität';
$lang['AdminTickets.add.heading_staff_id'] = 'Zugewiesen an';
$lang['AdminTickets.add.heading_department'] = 'Abteilung';
$lang['AdminTickets.add.heading_client'] = 'Kunde';
$lang['AdminTickets.add.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.add.text_no_clients'] = 'Keine Kunden gefunden. Versuchen Sie die Suche erneut.';
$lang['AdminTickets.add.heading_search_client'] = 'Suche nach dem Kunden';
$lang['AdminTickets.add.boxtitle_add'] = 'Ticket öffnen';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Einreichen';
$lang['AdminTickets.index.text_no_tickets'] = 'Keine offenen Tickets gefunden. Versuchen Sie die Suche erneut.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Ticket-Nummer';
$lang['AdminTickets.index.text_to_status'] = 'Wechseln zu:';
$lang['AdminTickets.index.text_to_client'] = 'An den Kunden:';
$lang['AdminTickets.index.text_into_ticket'] = 'In Ticket:';
$lang['AdminTickets.index.text_with_selected'] = 'Mit ausgewählten Tickets auftreten:';
$lang['AdminTickets.index.no_results'] = 'Derzeit gibt es keine Tickets mit diesem Status.';
$lang['AdminTickets.index.last_reply_by'] = 'von';
$lang['AdminTickets.index.unassigned'] = 'Nicht zugewiesen';
$lang['AdminTickets.index.field_last_reply'] = 'Letzte Antwort';
$lang['AdminTickets.index.field_assigned_staff'] = 'Zugewiesen an';
$lang['AdminTickets.index.field_summary'] = 'Zusammenfassung';
$lang['AdminTickets.index.field_department_id'] = 'Abteilung';
$lang['AdminTickets.index.field_priority'] = 'Priorität';
$lang['AdminTickets.index.field_ticket_number'] = 'Ticket-Nummer';
$lang['AdminTickets.index.hours'] = '%1$s Stunden';
$lang['AdminTickets.index.hour'] = '1 Stunde';
$lang['AdminTickets.index.minutes'] = '%1$s Minuten';
$lang['AdminTickets.index.any'] = 'Jede';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Letzte Antwort';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Zugewiesen an';
$lang['AdminTickets.index.heading_summary'] = 'Zusammenfassung';
$lang['AdminTickets.index.heading_department_name'] = 'Abteilung';
$lang['AdminTickets.index.heading_priority'] = 'Priorität';
$lang['AdminTickets.index.heading_client'] = 'Kunde';
$lang['AdminTickets.index.heading_code'] = 'Ticket-Nummer';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Eintrittskarten';
$lang['AdminTickets.index.categorylink_createticket'] = 'Ticket öffnen';
$lang['AdminTickets.index.category_trash'] = 'Papierkorb';
$lang['AdminTickets.index.category_closed'] = 'Geschlossen';
$lang['AdminTickets.index.category_on_hold'] = 'In der Warteschleife';
$lang['AdminTickets.index.category_in_progress'] = 'In Arbeit';
$lang['AdminTickets.index.category_awaiting_reply'] = 'Erwartete Antwort des Kunden';
$lang['AdminTickets.index.category_open'] = 'Antwort der Dienststellen abwarten';
$lang['AdminTickets.text.unassigned'] = 'Nicht zugewiesen';
$lang['AdminTickets.search.page_title'] = 'Suchergebnisse für "%1$s"';
$lang['AdminTickets.reply.page_title'] = 'Support Manager > Ticket #%1$s';
$lang['AdminTickets.add.page_title'] = 'Support Manager > Ticket öffnen';
$lang['AdminTickets.index.page_title'] = 'Support Manager > Anfragen';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Es sind noch keine Mitarbeiter und/oder Abteilungen erstellt worden. Klicken Sie oben auf %1$s, um eine Abteilung zu erstellen, oder auf %2$s, um ein Personalmitglied zuzuweisen.';
$lang['AdminTickets.!success.ticket_delete'] = 'Die ausgewählten Tickets wurden erfolgreich gelöscht.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Die ausgewählten Tickets wurden erfolgreich aktualisiert.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Die ausgewählten Tickets wurden erfolgreich neu zugewiesen.';
$lang['AdminTickets.!success.ticket_merge'] = 'Die ausgewählten Tickets wurden erfolgreich in Ticket #%1$s zusammengeführt.';
$lang['AdminTickets.!success.ticket_split'] = 'Das Ticket #%1$s wurde erfolgreich in Ticket #%2$s aufgeteilt.';
$lang['AdminTickets.!success.ticket_updated'] = 'Das Ticket #%1$s wurde erfolgreich aktualisiert.';
$lang['AdminTickets.!success.ticket_created'] = 'Das Ticket #%1$s wurde erfolgreich geöffnet.';
$lang['AdminTickets.reply.text_contacts'] = 'Nicht ausgewählte Kontakte werden automatisch zum Ticket hinzugefügt, wenn sie darauf antworten.';
$lang['AdminTickets.reply.text_add_recipient'] = 'Empfänger hinzufügen';
$lang['AdminTickets.reply.heading_contacts'] = 'Kontakte';
$lang['AdminTickets.reply.heading_recipients'] = 'Empfänger';
$lang['AdminTickets.add.text_contacts'] = 'Nicht ausgewählte Kontakte werden automatisch zum Ticket hinzugefügt, wenn sie darauf antworten.';
$lang['AdminTickets.add.text_add_recipient'] = 'Empfänger hinzufügen';
$lang['AdminTickets.add.heading_contacts'] = 'Kontakte';
$lang['AdminTickets.add.heading_recipients'] = 'Empfänger';
